
# THIS FILE IS GENERATED FROM SKNANO SETUP.PY
short_version = '0.2.20'
version = '0.2.20'
full_version = '0.2.20'
git_revision = '2b597dda9c7622d95943c3ac8cf76a05c240c4a2'
release = True

if not release:
    version = full_version
